//sword.cs
datablock AudioProfile(PowerswordHitSound)
{
   filename    = "./PowerswordHit.wav";
   description = AudioClosest3d;
   preload = true;
};

datablock AudioProfile(PowerswordSwingSound)
{
   filename    = "./PowerswordSwing.wav";
   description = AudioClose3d;
   preload = true;
};

//effects
datablock ParticleData(PowerswordExplosionParticle)
{
   dragCoefficient      = 0;
   gravityCoefficient   = 0;
   inheritedVelFactor   = 0.2;
   constantAcceleration = 0.0;
   spinRandomMin = -500;
   spinRandomMax = 500;
   lifetimeMS           = 150;
   lifetimeVarianceMS   = 50;
   textureName          = "./power";
   colors[0]     = "1 1 1 0.9";
   colors[1]     = "0 0.5 1 0.0";
   sizes[0]      = 1.5;
   sizes[1]      = 2.5;
};

datablock ParticleEmitterData(PowerswordExplosionEmitter)
{
   ejectionPeriodMS = 6;
   periodVarianceMS = 0;
   ejectionVelocity = 0.5;
   velocityVariance = 0.25;
   ejectionOffset   = 0.0;
   thetaMin         = 0;
   thetaMax         = 60;
   phiReferenceVel  = 0;
   phiVariance      = 360;
   overrideAdvance = false;
   particles = "PowerswordExplosionParticle";

   uiName = "Power Sword Hit";
};

datablock ExplosionData(PowerswordExplosion)
{
   //explosionShape = "";
   lifeTimeMS = 150;

   soundProfile = PowerswordHitSound;

   particleEmitter = PowerswordExplosionEmitter;
   particleDensity = 10;
   particleRadius = 0.2;
   
   faceViewer     = true;
   explosionScale = "1 1 1";

   shakeCamera = true;
   camShakeFreq = "20.0 22.0 20.0";
   camShakeAmp = "1.0 1.0 1.0";
   camShakeDuration = 0.5;
   camShakeRadius = 10.0;

   // Dynamic light
   lightStartRadius = 3;
   lightEndRadius = 0;
   lightStartColor = "0.5 0.75 1 1";
   lightEndColor = "0 0.5 1 0";
};


//projectile
AddDamageType("Powersword",   '<bitmap:add-ons/Weapon_WH40k_Imperium/CI_Powersword> %1',    '%2 <bitmap:add-ons/Weapon_WH40k_Imperium/CI_Powersword> %1',0.75,1);
datablock ProjectileData(PowerswordProjectile)
{
   directDamage        = 50;
   directDamageType  = $DamageType::Powersword;
   radiusDamageType  = $DamageType::Powersword;
   explosion           = PowerswordExplosion;
   //particleEmitter     = ass;

   muzzleVelocity      = 200;
   velInheritFactor    = 1;

   armingDelay         = 0;
   lifetime            = 70;
   fadeDelay           = 0;
   bounceElasticity    = 0;
   bounceFriction      = 0;
   isBallistic         = false;
   gravityMod = 0.0;

   hasLight    = false;
   lightRadius = 1.5;
   lightColor  = "0.33 0.66 1";

   uiName = "Power Sword Slice";
};


//////////
// item //
//////////
datablock ItemData(PowerswordItem)
{
	category = "Weapon";  // Mission editor category
	className = "Weapon"; // For inventory system

	 // Basic Item Properties
	shapeFile = "./Powersword.dts";
	mass = 1;
	density = 0.2;
	elasticity = 0.2;
	friction = 0.6;
	emap = true;

	//gui stuff
	uiName = "Power Sword";
	iconName = "./Powersword";
	doColorShift = false;
	colorShiftColor = "0.471 0.471 0.471 1.000";

	 // Dynamic properties defined by the scripts
	image = PowerswordImage;
	canDrop = true;
};

////////////////
//weapon image//
////////////////
datablock ShapeBaseImageData(PowerswordImage)
{
   // Basic Item properties
   shapeFile = "./Powersword.dts";
   emap = true;

   // Specify mount point & offset for 3rd person, and eye offset
   // for first person rendering.
   mountPoint = 0;
   offset = "0 0 0";

   // When firing from a point offset from the eye, muzzle correction
   // will adjust the muzzle vector to point to the eye LOS point.
   // Since this weapon doesn't actually fire from the muzzle point,
   // we need to turn this off.  
   correctMuzzleVector = false;

   eyeOffset = "0";

   // Add the WeaponImage namespace as a parent, WeaponImage namespace
   // provides some hooks into the inventory system.
   className = "WeaponImage";

   // Projectile && Ammo.
   item = PowerswordItem;
   ammo = " ";
   projectile = PowerswordProjectile;
   projectileType = Projectile;

   //melee particles shoot from eye node for consistancy
   melee = true;
   doRetraction = false;
   //raise your arm up or not
   armReady = true;

   //casing = " ";
   doColorShift = true;
   colorShiftColor = "0.471 0.471 0.471 1.000";

   // Images have a state system which controls how the animations
   // are run, which sounds are played, script callbacks, etc. This
   // state system is downloaded to the client so that clients can
   // predict state changes and animate accordingly.  The following
   // system supports basic ready->fire->reload transitions as
   // well as a no-ammo->dryfire idle state.

   // Initial start up state
	stateName[0]                     = "Activate";
	stateTimeoutValue[0]             = 0.5;
	stateTransitionOnTimeout[0]      = "Ready";

	stateName[1]                     = "Ready";
	stateTransitionOnTriggerDown[1]  = "PrePreFire";
	stateAllowImageChange[1]         = true;

	stateName[2]			= "PreFire";
	stateScript[2]                  = "onPreFire";
	stateAllowImageChange[2]        = false;
	stateTimeoutValue[2]            = 0.05;
	stateTransitionOnTimeout[2]     = "Fire";	
	stateSound[2]                    = PowerswordSwingSound;
	
	stateName[3]                    = "Fire";
	stateTransitionOnTimeout[3]     = "Wait";
	stateTimeoutValue[3]            = 0.05;
	stateFire[3]                    = true;
	stateAllowImageChange[3]        = false;
	stateSequence[3]                = "Fire";
	stateScript[3]                  = "onFire";
	stateWaitForTimeout[3]		= true;
	
	stateName[4]					= "Wait";
	stateTransitionOnTimeout[4]		= "Ready";
	stateTimeoutValue[4]			= 0.15;
	stateSequence[4]				= "Wait";
	stateScript[4]					= "onWait";

	stateName[5]			= "PrePreFire";
	stateScript[5]                  = "onPrePreFire";
	stateAllowImageChange[5]        = false;
	stateTimeoutValue[5]            = 0.05;
	stateTransitionOnTimeout[5]     = "PreFire";	
	
};

function PowerswordImage::onPrePreFire(%this, %obj, %slot)
{
	%obj.playthread(2, shiftAway);
	%obj.playthread(3, shiftRight);
}

function PowerswordImage::onPreFire(%this, %obj, %slot)
{
	%obj.playthread(2, shiftTo);
	%obj.playthread(3, shiftLeft);
}

//function PowerswordImage::onWait(%this, %obj, %slot)
//{	
//	%obj.playthread(2, root);
//}